==> pde-2.19.0.tgz: package/lib/hooks/common/platformStrategies.js <==
import { parseQueryString } from '@s-ui/js/lib/string/index.js';
import { trackedEventsLocalCache } from './trackedEventsLocalCache.js';

var getServerStrategy = function getServerStrategy() {
  return {
    getVariation: function getVariation(_ref) {
      var pde = _ref.pde,
          experimentName = _ref.experimentName,
          attributes = _ref.attributes,
          adapterId = _ref.adapterId;
      return pde.getVariation({
        pde: pde,
        name: experimentName,
        attributes: attributes,
        adapterId: adapterId
      });
    },
    trackExperiment: function trackExperiment() {},
    getForcedValue: function getForcedValue(_ref2) {
      var key = _ref2.key,
          queryString = _ref2.queryString;

      if (!queryString) {
        return;
      }

      var queryParams = parseQueryString(queryString);
      return queryParams["suipde_" + key];
    }
  };
};

var getBrowserStrategy = function getBrowserStrategy(_ref3) {
  var customTrackExperimentViewed = _ref3.customTrackExperimentViewed,
      cache = _ref3.cache;
  return {
    getVariation: function getVariation(_ref4) {
      var pde = _ref4.pde,
          experimentName = _ref4.experimentName,
          attributes = _ref4.attributes,
          adapterId = _ref4.adapterId;
      var variationName = pde.activateExperiment({
        name: experimentName,
        attributes: attributes,
        adapterId: adapterId
      });
      return variationName;
    },
    trackExperiment: function trackExperiment(_ref5) {
      var _window$analytics;

      var variationName = _ref5.variationName,
          experimentName = _ref5.experimentName;

      if (customTrackExperimentViewed) {
        return customTrackExperimentViewed({
          variationName: variationName,
          experimentName: experimentName
        });
      } // user is not part of the experiment


      if (!variationName) return; // if experiment has been already tracked

      if (cache.includes(experimentName, variationName)) return;

      if (!((_window$analytics = window.analytics) != null && _window$analytics.track)) {
        // eslint-disable-next-line no-console
        console.error("[sui-pde: useExperiment] window.analytics.track expected to exists but doesn't");
        return;
      }

      cache.push(experimentName, variationName);
      window.analytics.ready(function () {
        window.analytics.track('Experiment Viewed', {
          experimentName: experimentName,
          variationName: variationName
        });
      });
    },

    /**
     * @param {object} param
     * @param {string} key Experiment or feature flag key
     * @param {string} queryString Test purposes only
     * @returns {string|null}
     */
    getForcedValue: function getForcedValue(_ref6) {
      var key = _ref6.key,
          _ref6$queryString = _ref6.queryString,
          queryString = _ref6$queryString === void 0 ? document.location.search : _ref6$queryString;
      var queryParams = parseQueryString(queryString);
      return queryParams["suipde_" + key];
    }
  };
};
/**
 * Returns the implementation of experiment related methods depending on
 * which platform we are server/browser
 * @param {object} param
 * @param {function} [param.customTrackExperimentViewed]
 * @returns object
 */


export var getPlatformStrategy = function getPlatformStrategy(_temp) {
  var _ref7 = _temp === void 0 ? {} : _temp,
      customTrackExperimentViewed = _ref7.customTrackExperimentViewed;

  var isNode = typeof window === 'undefined';

  if (isNode) {
    return getServerStrategy();
  }

  trackedEventsLocalCache.init();
  return getBrowserStrategy({
    customTrackExperimentViewed: customTrackExperimentViewed,
    cache: trackedEventsLocalCache
  });
};

==> pde-2.21.0.tgz: package/lib/hooks/common/platformStrategies.js <==
import { parseQueryString } from '@s-ui/js/lib/string/index.js';
import { trackedEventsLocalCache } from './trackedEventsLocalCache.js';
var getServerStrategy = function getServerStrategy() {
  return {
    getVariation: function getVariation(_ref) {
      var pde = _ref.pde,
        experimentName = _ref.experimentName,
        attributes = _ref.attributes,
        adapterId = _ref.adapterId;
      return pde.getVariation({
        pde: pde,
        name: experimentName,
        attributes: attributes,
        adapterId: adapterId
      });
    },
    trackExperiment: function trackExperiment() {},
    getForcedValue: function getForcedValue(_ref2) {
      var key = _ref2.key,
        queryString = _ref2.queryString;
      if (!queryString) {
        return;
      }
      var queryParams = parseQueryString(queryString);
      return queryParams["suipde_" + key];
    }
  };
};
var getBrowserStrategy = function getBrowserStrategy(_ref3) {
  var customTrackExperimentViewed = _ref3.customTrackExperimentViewed,
    cache = _ref3.cache;
  return {
    getVariation: function getVariation(_ref4) {
      var pde = _ref4.pde,
        experimentName = _ref4.experimentName,
        attributes = _ref4.attributes,
        adapterId = _ref4.adapterId;
      var variationName = pde.activateExperiment({
        name: experimentName,
        attributes: attributes,
        adapterId: adapterId
      });
      return variationName;
    },
    trackExperiment: function trackExperiment(_ref5) {
      var _window$analytics;
      var variationName = _ref5.variationName,
        experimentName = _ref5.experimentName;
      if (customTrackExperimentViewed) {
        return customTrackExperimentViewed({
          variationName: variationName,
          experimentName: experimentName
        });
      }

      // user is not part of the experiment
      if (!variationName) return;

      // if experiment has been already tracked
      if (cache.includes(experimentName, variationName)) return;
      if (!((_window$analytics = window.analytics) != null && _window$analytics.track)) {
        // eslint-disable-next-line no-console
        console.error("[sui-pde: useExperiment] window.analytics.track expected to exists but doesn't");
        return;
      }
      cache.push(experimentName, variationName);
      window.analytics.ready(function () {
        window.analytics.track('Experiment Viewed', {
          experimentName: experimentName,
          variationName: variationName
        });
      });
    },
    /**
     * @param {object} param
     * @param {string} key Experiment or feature flag key
     * @param {string} queryString Test purposes only
     * @returns {string|null}
     */
    getForcedValue: function getForcedValue(_ref6) {
      var key = _ref6.key,
        _ref6$queryString = _ref6.queryString,
        queryString = _ref6$queryString === void 0 ? document.location.search : _ref6$queryString;
      var queryParams = parseQueryString(queryString);
      return queryParams["suipde_" + key];
    }
  };
};

/**
 * Returns the implementation of experiment related methods depending on
 * which platform we are server/browser
 * @param {object} param
 * @param {function} [param.customTrackExperimentViewed]
 * @returns object
 */
export var getPlatformStrategy = function getPlatformStrategy(_temp) {
  var _ref7 = _temp === void 0 ? {} : _temp,
    customTrackExperimentViewed = _ref7.customTrackExperimentViewed;
  var isNode = typeof window === 'undefined';
  if (isNode) {
    return getServerStrategy();
  }
  trackedEventsLocalCache.init();
  return getBrowserStrategy({
    customTrackExperimentViewed: customTrackExperimentViewed,
    cache: trackedEventsLocalCache
  });
};
